/* StringHelperTest.java
 *	Copyright 	(c) 2002, Brains2B.org
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that
 * the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice, this list of conditions and 
 * the following disclaimer. 
 * 2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and
 * the following disclaimer in the documentation and/or other materials provided with the distribution. 
 * 3. The name of the author may not be used to endorse or promote products derived from this software 
 * without specific prior written permission. 
 * 
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY 
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
 /* @#History
 * [When]		[Who]				[What]
 * 11/10/2002	dennis@brains2b.nl	Added test for matchBracket
 */
package test.org.brains2b.util;

import junit.framework.TestCase;
import junit.swingui.TestRunner;

import org.brains2b.util.StringHelper;

/** 
 * Unit test for org.brains2b.util.StringHelper
 *
 * @author <A HREF="MAILTO:dennis@brains2b.nl">dennis@brains2b.nl</A>
 * @version 0.10 [08/31/2002]
 * @see org.brains2b.util.StringHelper
 */
public class StringHelperTest extends TestCase {

	public static void main(String[] arguments) {
		TestRunner.run(StringHelperTest.class);
	}
	/**
	 * Constructor for StringHelperTest.
	 * @param arg0
	 */
	public StringHelperTest(String arg0) {
		super(arg0);
	}

	public void testInitCaps() {
		assertEquals("Foo",StringHelper.initCaps("foo",' '));
		assertEquals("Kung Foo",StringHelper.initCaps("kung foo",' '));
		assertEquals("Kung@Foo.com",StringHelper.initCaps("kung@foo.com",'@'));
		assertNull(StringHelper.initCaps(null,' '));
	}

	public void testStripper() {
		assertEquals("Foo",StringHelper.stripper("F o o ",' '));
		assertEquals("Kung Foo",StringHelper.stripper("K.u.n.g F.o.o",'.'));
		assertEquals("KungFoo.com",StringHelper.stripper("Kung@Foo.com",'@'));
		assertNull(StringHelper.stripper(null,' '));
	}

	public void testBaseOnly() {
		assertEquals("FOO",StringHelper.baseOnly("F o o."));
		assertEquals("KUNG42FOO",StringHelper.baseOnly("K.u.n.g 4-2 F.o.o"));
		assertEquals("ABRACADABRA",StringHelper.baseOnly("ab-ra ca-da|bra."));
		assertNull(StringHelper.baseOnly(null));
		
	}

	public void testBreakLine() {
		char lbreak=System.getProperty("line.separator").charAt(0);
		
		assertEquals("In another "+ lbreak +"moment "+ lbreak +"down went "+ lbreak +"Alice "+ lbreak + "after it"
			,StringHelper.breakLine("In another moment down went Alice after it",10));
		assertEquals("Nospacesinhere",StringHelper.breakLine("Nospacesinhere",10));
		assertEquals("Longer then the line, which should be broken.",StringHelper.breakLine("Longer then the line, which should be broken.",100));
		assertNull(StringHelper.breakLine(null,10));
		assertEquals("In "+ lbreak +"another "+ lbreak +"moment "+ lbreak + "down "+lbreak+"went "+lbreak+"Alice "+lbreak+"after "+ lbreak +"it",StringHelper.breakLine("In another moment down went Alice after it",0));
				
	}

	public void testLeftPad() {
		assertEquals("foo",StringHelper.leftPad("oo","f",3));
		assertEquals("foo",StringHelper.leftPad("kung foo","x",3));
		assertEquals("000001",StringHelper.leftPad("1","0",6));
		assertEquals("000  1",StringHelper.leftPad("  1","0",6));
		assertEquals("000", StringHelper.leftPad(null,"0",3));
		try { 
			StringHelper.leftPad("1",null,3);
			assertTrue(false);
		} catch (NullPointerException npex) {
			assertTrue(true);
		}
	}

	public void testRightPad() {
		assertEquals("foo",StringHelper.rightPad("f","o",3));
		assertEquals("foo",StringHelper.rightPad("foochi","x",3));
		assertEquals("100000",StringHelper.rightPad("1","0",6));
		assertEquals("  1000",StringHelper.rightPad("  1","0",6));
		assertEquals("000", StringHelper.rightPad(null,"0",3));
		try { 
			StringHelper.rightPad("1",null,3);
			assertTrue(false);
		} catch (NullPointerException npex) {
			assertTrue(true);
		}
	}

	public void testMatchBracketIntString() {
		assertEquals(-1,StringHelper.matchBracket(0,"does not contain a quote"));
		assertEquals(21,StringHelper.matchBracket(0,"\"does contain a quote\""));
		assertEquals(9, StringHelper.matchBracket(0,"(contains) (multiple) (quotes)"));
		assertEquals(25, StringHelper.matchBracket(0,"((contains nested) quotes)"));
		assertEquals(17, StringHelper.matchBracket(1,"((contains nested) quotes)"));
	}

	public void testMatchBracketCharString() {
		assertEquals(-1,StringHelper.matchBracket('\"',"does not contain a quote"));
		assertEquals(14,StringHelper.matchBracket('\"',"does\" contain \" a quote"));
		assertEquals(9, StringHelper.matchBracket('(',"(contains) (multiple) (quotes)"));
		assertEquals(25, StringHelper.matchBracket('(',"((contains nested) quotes)"));

	}	
}
